@@ -3,7 +3,7 @@ package Catalyst::Action::RenderView;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use base 'Catalyst::Action';
 
@@ -145,6 +145,12 @@ you can set it up like this:
 
 Marcus Ramberg <marcus@thefeed.no>
 
+=head1 COPYRIGHT
+
+Copyright (c) 2006 - 2009
+the Catalyst::Action::RenderView L</AUTHOR>
+as listed above.
+
 =head1 LICENSE
 
 This library is free software. You can redistribute it and/or modify it
